@@ -1,5 +1,6 @@
 //! rsw clean
 
+use std::collections::HashMap;
 use std::path::PathBuf;
 
 use crate::config::RswConfig;
@@ -11,7 +12,8 @@ pub struct Clean;
 // clean: link & build
 impl Clean {
     pub fn new(config: RswConfig) {
-        let mut crates: Vec<String> = [].to_vec();
+        let mut crates: Vec<String> = Vec::new();
+        let mut path_map: HashMap<String, PathBuf> = HashMap::new();
 
         for i in &config.crates {
             let rsw_crate = i.clone();
@@ -22,13 +24,17 @@ impl Clean {
             let pkg_path = crate_path.to_string_lossy().to_string();
 
             if path_exists(&crate_path) {
-                std::fs::remove_dir_all(crate_path).unwrap();
-                print(RswInfo::Clean("package".into(), pkg_path));
+                path_map.insert(pkg_path, crate_path);
             }
 
             crates.push(rsw_crate.name);
         }
 
-        Link::unlink(&config.cli.unwrap().to_owned(), &crates);
+        Link::unlink(&config.cli.unwrap().to_owned(), crates);
+
+        for (_crate, _path) in path_map {
+            std::fs::remove_dir_all(_path).unwrap();
+            print(RswInfo::Clean("package".into(), _crate));
+        }
     }
 }
