@@ -5,7 +5,8 @@ use notify::{DebouncedEvent::*, RecursiveMode::*, Watcher};
 use path_clean::PathClean;
 use regex::Regex;
 use std::{
-    collections::HashMap, path::PathBuf, rc::Rc, sync::mpsc::channel, thread::sleep, time::Duration,
+    collections::HashMap, path::PathBuf, sync::mpsc::channel, sync::Arc, thread::sleep,
+    time::Duration,
 };
 
 use crate::config::{CrateConfig, RswConfig};
@@ -14,12 +15,15 @@ use crate::core::{Build, RswErr, RswInfo};
 use crate::utils::{get_root, print};
 
 pub struct Watch {
-    config: Rc<RswConfig>,
-    callback: Box<dyn Fn(&CrateConfig, PathBuf)>,
+    config: Arc<RswConfig>,
+    callback: Arc<dyn Fn(&CrateConfig, PathBuf) + Send + Sync + 'static>,
 }
 
 impl Watch {
-    pub fn new(config: Rc<RswConfig>, callback: Box<dyn Fn(&CrateConfig, PathBuf)>) -> Watch {
+    pub fn new(
+        config: Arc<RswConfig>,
+        callback: Arc<dyn Fn(&CrateConfig, PathBuf) + Send + Sync + 'static>,
+    ) -> Watch {
         Watch { config, callback }
     }
     pub fn init(self) {
@@ -55,6 +59,7 @@ impl Watch {
         print(RswInfo::SplitLine);
 
         let (gitignore, _) = Gitignore::new("./.watchignore");
+        let mut build_task_join_handle: Option<tokio::task::JoinHandle<()>> = None;
 
         loop {
             let first_event = rx.recv().unwrap();
@@ -67,7 +72,7 @@ impl Watch {
 
                 match event {
                     Write(path) | Remove(path) | Rename(_, path) => {
-                        let path = Rc::new(path);
+                        let path = Arc::new(path);
 
                         let path2 = path.to_string_lossy().to_string();
                         let project_path_split = path2.split(&root);
@@ -82,20 +87,33 @@ impl Watch {
                                 .unwrap()
                                 .is_match(path.to_owned().to_str().unwrap())
                             {
-                                let crate_config = *crate_map.get(key).unwrap();
+                                let crate_config = (*crate_map.get(key).unwrap()).clone();
                                 print(RswInfo::CrateChange(path.clone().to_path_buf()));
-                                let is_ok = Build::new(
-                                    crate_config.clone(),
-                                    "watch",
-                                    config.cli.to_owned().unwrap(),
-                                    false,
-                                )
-                                .init();
 
-                                if is_ok {
-                                    caller(crate_config, path.clone().to_path_buf());
+                                if let Some(join_handle) = build_task_join_handle {
+                                    debug!("abort building task");
+                                    join_handle.abort();
                                 }
 
+                                let config = config.clone();
+                                let caller = caller.clone();
+                                let path = path.clone();
+                                let join_handle = tokio::spawn(async move {
+                                    let is_ok = Build::new(
+                                        crate_config.clone(),
+                                        "watch",
+                                        config.cli.to_owned().unwrap(),
+                                        false,
+                                    )
+                                    .init();
+
+                                    if is_ok {
+                                        caller(&crate_config, path.clone().to_path_buf());
+                                    }
+                                });
+
+                                build_task_join_handle = Some(join_handle);
+
                                 break;
                             }
                         }
